
.. _AWS Step Functions: https://docs.aws.amazon.com/step-functions/latest/dg/welcome.html
.. _AWS CloudFormation: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/Welcome.html
.. _Troposphere: https://troposphere.readthedocs.io

.. _Pass: https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-pass-state.html
.. _Task: https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-task-state.html
.. _Choice: https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-choice-state.html
.. _Wait: https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-wait-state.html
.. _Succeed: https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-succeed-state.html
.. _Fail: https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-fail-state.html
.. _Parallel: https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-parallel-state.html
.. _Map: https://docs.aws.amazon.com/step-functions/latest/dg/amazon-states-language-map-state.html
